.. _login_module:

:mod:`cubicweb.pyramid.login`
-----------------------------

.. automodule:: cubicweb.pyramid.login

    .. autofunction:: includeme


    Views
    -----

    .. autofunction:: login_form
    .. autofunction:: login_password_login
    .. autofunction:: login_already_loggedin
